/*
 * ModeShape (http://www.modeshape.org)
 * See the COPYRIGHT.txt file distributed with this work for information
 * regarding copyright ownership.  Some portions may be licensed
 * to Red Hat, Inc. under one or more contributor license agreements.
 * See the AUTHORS.txt file in the distribution for a full listing of 
 * individual contributors.
 *
 * ModeShape is free software. Unless otherwise indicated, all code in ModeShape
 * is licensed to you under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 * 
 * ModeShape is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.modeshape.jcr.query.model;

/**
 * A representation of a non-correlated subquery. This component uses composition to hold the various types of QueryCommand
 * objects, rather than inheriting from StaticOperand and QueryCommand.
 */
public class Subquery implements StaticOperand, org.modeshape.jcr.api.query.qom.Subquery {

    private static final long serialVersionUID = 1L;

    public static final String VARIABLE_PREFIX = "__mode:subquery";

    public static boolean isSubqueryVariableName( String variableName ) {
        return variableName.startsWith(VARIABLE_PREFIX);
    }

    private final QueryCommand query;

    /**
     * Create a new subquery component that uses the supplied query as the subquery expression.
     * 
     * @param query the Command representing the subquery.
     */
    public Subquery( QueryCommand query ) {
        this.query = query;
    }

    @Override
    public QueryCommand getQuery() {
        return query;
    }

    @Override
    public void accept( Visitor visitor ) {
        visitor.visit(this);
    }

    @Override
    public String toString() {
        return Visitors.readable(this);
    }

    @Override
    public int hashCode() {
        return query.hashCode();
    }

    @Override
    public boolean equals( Object obj ) {
        if (obj == this) return true;
        if (obj instanceof Subquery) {
            Subquery that = (Subquery)obj;
            return this.query.equals(that.query) || this.query.toString().equals(that.query.toString());
        }
        return false;
    }
}
